from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GainCls:
	"""Gain commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gain", core, parent)

	def set(self, gain: float) -> None:
		"""SCPI: SYSTem:CONFigure:DUT:GAIN \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.dut.gain.set(gain = 1.0) \n
		This command defines the expected 'gain' of the DUT. The application uses the 'gain' for automatic reference level
		detection. \n
			:param gain: Range: 10 to 1000, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(gain)
		self._core.io.write(f'SYSTem:CONFigure:DUT:GAIN {param}')

	def get(self) -> float:
		"""SCPI: SYSTem:CONFigure:DUT:GAIN \n
		Snippet: value: float = driver.applications.k30NoiseFigure.system.configure.dut.gain.get() \n
		This command defines the expected 'gain' of the DUT. The application uses the 'gain' for automatic reference level
		detection. \n
			:return: gain: Range: 10 to 1000, Unit: DB"""
		response = self._core.io.query_str(f'SYSTem:CONFigure:DUT:GAIN?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CreferenceCls:
	"""Creference commands group definition. 14 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("creference", core, parent)

	@property
	def pdetect(self):
		"""pdetect commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdetect'):
			from .Pdetect import PdetectCls
			self._pdetect = PdetectCls(self._core, self._cmd_group)
		return self._pdetect

	@property
	def guard(self):
		"""guard commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_guard'):
			from .Guard import GuardCls
			self._guard = GuardCls(self._core, self._cmd_group)
		return self._guard

	@property
	def value(self):
		"""value commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_value'):
			from .Value import ValueCls
			self._value = ValueCls(self._core, self._cmd_group)
		return self._value

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def preference(self):
		"""preference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preference'):
			from .Preference import PreferenceCls
			self._preference = PreferenceCls(self._core, self._cmd_group)
		return self._preference

	@property
	def freference(self):
		"""freference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_freference'):
			from .Freference import FreferenceCls
			self._freference = FreferenceCls(self._core, self._cmd_group)
		return self._freference

	@property
	def srange(self):
		"""srange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srange'):
			from .Srange import SrangeCls
			self._srange = SrangeCls(self._core, self._cmd_group)
		return self._srange

	@property
	def harmonics(self):
		"""harmonics commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_harmonics'):
			from .Harmonics import HarmonicsCls
			self._harmonics = HarmonicsCls(self._core, self._cmd_group)
		return self._harmonics

	def clone(self) -> 'CreferenceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CreferenceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def nonePy(self):
		"""nonePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nonePy'):
			from .NonePy import NonePyCls
			self._nonePy = NonePyCls(self._core, self._cmd_group)
		return self._nonePy

	@property
	def invert(self):
		"""invert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_invert'):
			from .Invert import InvertCls
			self._invert = InvertCls(self._core, self._cmd_group)
		return self._invert

	def set(self, selection: float, state: bool) -> None:
		"""SCPI: HCOPy:TREPort:TEST:SELect \n
		Snippet: driver.hardCopy.treport.test.select.set(selection = 1.0, state = False) \n
		No command help available \n
			:param selection: No help available
			:param state: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('selection', selection, DataType.Float), ArgSingle('state', state, DataType.Boolean))
		self._core.io.write(f'HCOPy:TREPort:TEST:SELect {param}'.rstrip())

	def clone(self) -> 'SelectCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SelectCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, level: enums.LowHigh, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: OUTPut:TRIGger<tp>:LEVel \n
		Snippet: driver.applications.k50Spurious.output.trigger.level.set(level = enums.LowHigh.HIGH, triggerPort = repcap.TriggerPort.Default) \n
		This command defines the level of the (TTL compatible) signal generated at the trigger output. This command works only if
		you have selected a user-defined output with method RsFswp.Applications.K30_NoiseFigure.Output.Trigger.Otype.set. \n
			:param level: HIGH 5 V LOW 0 V
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.enum_scalar_to_str(level, enums.LowHigh)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'OUTPut:TRIGger{triggerPort_cmd_val}:LEVel {param}')

	# noinspection PyTypeChecker
	def get(self, triggerPort=repcap.TriggerPort.Default) -> enums.LowHigh:
		"""SCPI: OUTPut:TRIGger<tp>:LEVel \n
		Snippet: value: enums.LowHigh = driver.applications.k50Spurious.output.trigger.level.get(triggerPort = repcap.TriggerPort.Default) \n
		This command defines the level of the (TTL compatible) signal generated at the trigger output. This command works only if
		you have selected a user-defined output with method RsFswp.Applications.K30_NoiseFigure.Output.Trigger.Otype.set. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: level: HIGH 5 V LOW 0 V"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'OUTPut:TRIGger{triggerPort_cmd_val}:LEVel?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums
from ... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, source: enums.InputSource, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:SELect \n
		Snippet: driver.inputPy.select.set(source = enums.InputSource.ABBand, inputIx = repcap.InputIx.Default) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSWP. \n
			:param source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFswp.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(source, enums.InputSource)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:SELect {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DirectedCls:
	"""Directed commands group definition. 11 total commands, 7 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("directed", core, parent)

	@property
	def settings(self):
		"""settings commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_settings'):
			from .Settings import SettingsCls
			self._settings = SettingsCls(self._core, self._cmd_group)
		return self._settings

	@property
	def nfft(self):
		"""nfft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nfft'):
			from .Nfft import NfftCls
			self._nfft = NfftCls(self._core, self._cmd_group)
		return self._nfft

	@property
	def refLevel(self):
		"""refLevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refLevel'):
			from .RefLevel import RefLevelCls
			self._refLevel = RefLevelCls(self._core, self._cmd_group)
		return self._refLevel

	@property
	def inputPy(self):
		"""inputPy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def loffset(self):
		"""loffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_loffset'):
			from .Loffset import LoffsetCls
			self._loffset = LoffsetCls(self._core, self._cmd_group)
		return self._loffset

	@property
	def mfRbw(self):
		"""mfRbw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mfRbw'):
			from .MfRbw import MfRbwCls
			self._mfRbw = MfRbwCls(self._core, self._cmd_group)
		return self._mfRbw

	@property
	def pexcursion(self):
		"""pexcursion commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pexcursion'):
			from .Pexcursion import PexcursionCls
			self._pexcursion = PexcursionCls(self._core, self._cmd_group)
		return self._pexcursion

	def save(self, filename: str) -> None:
		"""SCPI: [SENSe]:DIRected:SAVE \n
		Snippet: driver.applications.k50Spurious.sense.directed.save(filename = '1') \n
		Saves the current directed search configuration to a user-defined .csv file for later use.
		The result is a comma-separated list of values with the following syntax for each span: <No>,<Frequency>,<SearchSpan>,
		<DetThreshold>,<SNR>,<DetectMode> For details on the parameters see 'Directed Search Measurement settings') . \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DIRected:SAVE {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SENSe]:DIRected:LOAD \n
		Snippet: driver.applications.k50Spurious.sense.directed.load(filename = '1') \n
		Loads a stored search configuration from a .csv file. The current settings in the table are overwritten by the settings
		in the file! \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DIRected:LOAD {param}')

	def clone(self) -> 'DirectedCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DirectedCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsummaryCls:
	"""Msummary commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("msummary", core, parent)

	def set(self, time_offset: float, meas_time: float, pulse_period: float, of_pulses: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:MSUMmary \n
		Snippet: driver.calculate.marker.function.msummary.set(time_offset = 1.0, meas_time = 1.0, pulse_period = 1.0, of_pulses = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param time_offset: No help available
			:param meas_time: No help available
			:param pulse_period: No help available
			:param of_pulses: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('time_offset', time_offset, DataType.Float), ArgSingle('meas_time', meas_time, DataType.Float), ArgSingle('pulse_period', pulse_period, DataType.Float), ArgSingle('of_pulses', of_pulses, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:MSUMmary {param}'.rstrip())

	# noinspection PyTypeChecker
	class MsummaryStruct(StructBase):
		"""Response structure. Fields: \n
			- Time_Offset: float: No parameter help available
			- Meas_Time: float: No parameter help available
			- Pulse_Period: float: No parameter help available
			- Of_Pulses: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Time_Offset'),
			ArgStruct.scalar_float('Meas_Time'),
			ArgStruct.scalar_float('Pulse_Period'),
			ArgStruct.scalar_float('Of_Pulses')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Time_Offset: float = None
			self.Meas_Time: float = None
			self.Pulse_Period: float = None
			self.Of_Pulses: float = None

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> MsummaryStruct:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:MSUMmary \n
		Snippet: value: MsummaryStruct = driver.calculate.marker.function.msummary.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: structure: for return value, see the help for MsummaryStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:MSUMmary?', self.__class__.MsummaryStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TransferCls:
	"""Transfer commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("transfer", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:FPLan:TRANsfer \n
		Snippet: driver.applications.k50Spurious.sense.fplan.transfer.set() \n
		This command will transfer all frequencies that result out of the current frequency plan settings to the directed search
		settings. For details see 'Frequency plan and spur identification'. \n
		"""
		self._core.io.write(f'SENSe:FPLan:TRANsfer')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:FPLan:TRANsfer \n
		Snippet: driver.applications.k50Spurious.sense.fplan.transfer.set_with_opc() \n
		This command will transfer all frequencies that result out of the current frequency plan settings to the directed search
		settings. For details see 'Frequency plan and spur identification'. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:FPLan:TRANsfer', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IQ:OSC:BALanced[:STATe] \n
		Snippet: driver.applications.iqAnalyzer.inputPy.iq.osc.balanced.state.set(state = False, inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param state: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.bool_to_str(state)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IQ:OSC:BALanced:STATe {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> bool:
		"""SCPI: INPut<ip>:IQ:OSC:BALanced[:STATe] \n
		Snippet: value: bool = driver.applications.iqAnalyzer.inputPy.iq.osc.balanced.state.get(inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: state: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:OSC:BALanced:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LowerCls:
	"""Lower commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lower", core, parent)

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def margin(self):
		"""margin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_margin'):
			from .Margin import MarginCls
			self._margin = MarginCls(self._core, self._cmd_group)
		return self._margin

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def shift(self):
		"""shift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_shift'):
			from .Shift import ShiftCls
			self._shift = ShiftCls(self._core, self._cmd_group)
		return self._shift

	@property
	def spacing(self):
		"""spacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spacing'):
			from .Spacing import SpacingCls
			self._spacing = SpacingCls(self._core, self._cmd_group)
		return self._spacing

	@property
	def threshold(self):
		"""threshold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_threshold'):
			from .Threshold import ThresholdCls
			self._threshold = ThresholdCls(self._core, self._cmd_group)
		return self._threshold

	def clone(self) -> 'LowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetCls:
	"""Set commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("set", core, parent)

	# noinspection PyTypeChecker
	class SetStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- State_Peak: bool: No parameter help available
			- State_Rms: bool: No parameter help available
			- State_Avg: bool: No parameter help available
			- Trigger_Source: enums.TriggerSourceListPower: No parameter help available
			- Trigger_Slope: enums.SlopeType: No parameter help available
			- Trigger_Offset: float: No parameter help available
			- Gate_Length: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('State_Peak'),
			ArgStruct.scalar_bool('State_Rms'),
			ArgStruct.scalar_bool('State_Avg'),
			ArgStruct.scalar_enum('Trigger_Source', enums.TriggerSourceListPower),
			ArgStruct.scalar_enum('Trigger_Slope', enums.SlopeType),
			ArgStruct.scalar_float('Trigger_Offset'),
			ArgStruct.scalar_float('Gate_Length')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State_Peak: bool = None
			self.State_Rms: bool = None
			self.State_Avg: bool = None
			self.Trigger_Source: enums.TriggerSourceListPower = None
			self.Trigger_Slope: enums.SlopeType = None
			self.Trigger_Offset: float = None
			self.Gate_Length: float = None

	def set(self, structure: SetStruct) -> None:
		"""SCPI: [SENSe]:LIST:POWer:SET \n
		Snippet with structure: \n
		structure = driver.sense.listPy.power.set.SetStruct() \n
		structure.State_Peak: bool = False \n
		structure.State_Rms: bool = False \n
		structure.State_Avg: bool = False \n
		structure.Trigger_Source: enums.TriggerSourceListPower = enums.TriggerSourceListPower.EXT2 \n
		structure.Trigger_Slope: enums.SlopeType = enums.SlopeType.NEGative \n
		structure.Trigger_Offset: float = 1.0 \n
		structure.Gate_Length: float = 1.0 \n
		driver.sense.listPy.power.set.set(structure) \n
		No command help available \n
			:param structure: for set value, see the help for SetStruct structure arguments.
		"""
		self._core.io.write_struct(f'SENSe:LIST:POWer:SET', structure)

	def get(self) -> SetStruct:
		"""SCPI: [SENSe]:LIST:POWer:SET \n
		Snippet: value: SetStruct = driver.sense.listPy.power.set.get() \n
		No command help available \n
			:return: structure: for return value, see the help for SetStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:LIST:POWer:SET?', self.__class__.SetStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SOURce:VOLTage[:STATe] \n
		Snippet: driver.source.voltage.state.set(state = False) \n
		This command turns DC power sources on and off in general. When you turn off the DC power sources, no power is supplied
		even when you have turned on one of the sources individually with one of the following commands.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- method RsFswp.Source.Voltage.Auxiliary.Level.State.set
			- method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.Control.Level.State.set
			- method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.Power.Level.State.set
		Note that you can turn on the global power supply if at least one of the individual supplies has been turned on. \n
			:param state: ON | 1 DC power sources are ready for use. OFF | 0 DC power sources are turned off.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce:VOLTage:STATe {param}')

	def get(self) -> bool:
		"""SCPI: SOURce:VOLTage[:STATe] \n
		Snippet: value: bool = driver.source.voltage.state.get() \n
		This command turns DC power sources on and off in general. When you turn off the DC power sources, no power is supplied
		even when you have turned on one of the sources individually with one of the following commands.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- method RsFswp.Source.Voltage.Auxiliary.Level.State.set
			- method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.Control.Level.State.set
			- method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.Power.Level.State.set
		Note that you can turn on the global power supply if at least one of the individual supplies has been turned on. \n
			:return: state: ON | 1 DC power sources are ready for use. OFF | 0 DC power sources are turned off."""
		response = self._core.io.query_str(f'SOURce:VOLTage:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ContinuousCls:
	"""Continuous commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("continuous", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INITiate:CONTinuous \n
		Snippet: driver.applications.k60Transient.initiate.continuous.set(state = False) \n
		This command controls the measurement mode for an individual channel. Note that in single measurement mode, you can
		synchronize to the end of the measurement with *OPC, *OPC? or *WAI. In continuous measurement mode, synchronization to
		the end of the measurement is not possible. Thus, it is not recommended that you use continuous measurement mode in
		remote control, as results like trace data or markers are only valid after a single measurement end synchronization.
		If the measurement mode is changed for a channel while the Sequencer is active the mode is only considered the next time
		the measurement in that channel is activated by the Sequencer. \n
			:param state: ON | OFF | 0 | 1 ON | 1 Continuous measurement OFF | 0 Single measurement
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INITiate:CONTinuous {param}')

	def get(self) -> bool:
		"""SCPI: INITiate:CONTinuous \n
		Snippet: value: bool = driver.applications.k60Transient.initiate.continuous.get() \n
		This command controls the measurement mode for an individual channel. Note that in single measurement mode, you can
		synchronize to the end of the measurement with *OPC, *OPC? or *WAI. In continuous measurement mode, synchronization to
		the end of the measurement is not possible. Thus, it is not recommended that you use continuous measurement mode in
		remote control, as results like trace data or markers are only valid after a single measurement end synchronization.
		If the measurement mode is changed for a channel while the Sequencer is active the mode is only considered the next time
		the measurement in that channel is activated by the Sequencer. \n
			:return: state: ON | OFF | 0 | 1 ON | 1 Continuous measurement OFF | 0 Single measurement"""
		response = self._core.io.query_str(f'INITiate:CONTinuous?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AcDcCls:
	"""AcDc commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("acDc", core, parent)

	def set(self, state: enums.Synchronization) -> None:
		"""SCPI: INSTrument:COUPle:ACDC \n
		Snippet: driver.instrument.couple.acDc.set(state = enums.Synchronization.ALL) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.enum_scalar_to_str(state, enums.Synchronization)
		self._core.io.write(f'INSTrument:COUPle:ACDC {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.Synchronization:
		"""SCPI: INSTrument:COUPle:ACDC \n
		Snippet: value: enums.Synchronization = driver.instrument.couple.acDc.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'INSTrument:COUPle:ACDC?')
		return Conversions.str_to_scalar_enum(response, enums.Synchronization)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CopyCls:
	"""Copy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("copy", core, parent)

	def set(self, line: int, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:COPY \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.copy.set(line = 1, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command copies a limit line. \n
			:param line: 1 to 8 number of the new limit line name String containing the name of the limit line.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(line)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:COPY {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> int:
		"""SCPI: CALCulate<n>:LIMit<li>:COPY \n
		Snippet: value: int = driver.applications.k30NoiseFigure.calculate.limit.copy.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command copies a limit line. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: line: 1 to 8 number of the new limit line name String containing the name of the limit line."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:COPY?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:FREQuency:OFFSet \n
		Snippet: driver.sense.frequency.offset.set(frequency = 1.0) \n
		This command defines a frequency offset. If this value is not 0 Hz, the application assumes that the input signal was
		frequency shifted outside the application. All results of type 'frequency' will be corrected for this shift numerically
		by the application. See also 'Frequency Offset'. Note: In MSRA mode, the setting command is only available for the MSRA
		primary application. For MSRA secondary applications, only the query command is available. \n
			:param frequency: Range: -1 THz to 1 THz, Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:FREQuency:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:OFFSet \n
		Snippet: value: float = driver.sense.frequency.offset.get() \n
		This command defines a frequency offset. If this value is not 0 Hz, the application assumes that the input signal was
		frequency shifted outside the application. All results of type 'frequency' will be corrected for this shift numerically
		by the application. See also 'Frequency Offset'. Note: In MSRA mode, the setting command is only available for the MSRA
		primary application. For MSRA secondary applications, only the query command is available. \n
			:return: frequency: No help available"""
		response = self._core.io.query_str(f'SENSe:FREQuency:OFFSet?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:PATTern:MAPPing:CATalog \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.pattern.mapping.catalog.get() \n
		This command queries the names of all mappings that are available for the pattern for the current modulation type and
		order. A mapping describes the assignment of constellation points to symbols. This command is only available if the
		additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: mappings: list A comma-separated list of strings, with one string for each mapping name."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:MAPPing:CATalog?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def set(self, offset: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: TRIGger<tp>[:SEQuence]:HOLDoff[:TIME] \n
		Snippet: driver.applications.k70Vsa.trigger.sequence.holdoff.time.set(offset = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		Defines the time offset between the trigger event and the start of the measurement. \n
			:param offset: The allowed range is 0 s to 30 s. Unit: S
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(offset)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'TRIGger{triggerPort_cmd_val}:SEQuence:HOLDoff:TIME {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: TRIGger<tp>[:SEQuence]:HOLDoff[:TIME] \n
		Snippet: value: float = driver.applications.k70Vsa.trigger.sequence.holdoff.time.get(triggerPort = repcap.TriggerPort.Default) \n
		Defines the time offset between the trigger event and the start of the measurement. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: offset: The allowed range is 0 s to 30 s. Unit: S"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'TRIGger{triggerPort_cmd_val}:SEQuence:HOLDoff:TIME?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FunctionCls:
	"""Function commands group definition. 90 total commands, 17 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("function", core, parent)

	@property
	def afPhase(self):
		"""afPhase commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_afPhase'):
			from .AfPhase import AfPhaseCls
			self._afPhase = AfPhaseCls(self._core, self._cmd_group)
		return self._afPhase

	@property
	def fpeaks(self):
		"""fpeaks commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_fpeaks'):
			from .Fpeaks import FpeaksCls
			self._fpeaks = FpeaksCls(self._core, self._cmd_group)
		return self._fpeaks

	@property
	def ndbDown(self):
		"""ndbDown commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndbDown'):
			from .NdbDown import NdbDownCls
			self._ndbDown = NdbDownCls(self._core, self._cmd_group)
		return self._ndbDown

	@property
	def noise(self):
		"""noise commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import NoiseCls
			self._noise = NoiseCls(self._core, self._cmd_group)
		return self._noise

	@property
	def pnoise(self):
		"""pnoise commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pnoise'):
			from .Pnoise import PnoiseCls
			self._pnoise = PnoiseCls(self._core, self._cmd_group)
		return self._pnoise

	@property
	def mdepth(self):
		"""mdepth commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mdepth'):
			from .Mdepth import MdepthCls
			self._mdepth = MdepthCls(self._core, self._cmd_group)
		return self._mdepth

	@property
	def toi(self):
		"""toi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_toi'):
			from .Toi import ToiCls
			self._toi = ToiCls(self._core, self._cmd_group)
		return self._toi

	@property
	def bpower(self):
		"""bpower commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_bpower'):
			from .Bpower import BpowerCls
			self._bpower = BpowerCls(self._core, self._cmd_group)
		return self._bpower

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def cstep(self):
		"""cstep commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cstep'):
			from .Cstep import CstepCls
			self._cstep = CstepCls(self._core, self._cmd_group)
		return self._cstep

	@property
	def reference(self):
		"""reference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	@property
	def ademod(self):
		"""ademod commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_ademod'):
			from .Ademod import AdemodCls
			self._ademod = AdemodCls(self._core, self._cmd_group)
		return self._ademod

	@property
	def power(self):
		"""power commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def strack(self):
		"""strack commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_strack'):
			from .Strack import StrackCls
			self._strack = StrackCls(self._core, self._cmd_group)
		return self._strack

	@property
	def summary(self):
		"""summary commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_summary'):
			from .Summary import SummaryCls
			self._summary = SummaryCls(self._core, self._cmd_group)
		return self._summary

	@property
	def msummary(self):
		"""msummary commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_msummary'):
			from .Msummary import MsummaryCls
			self._msummary = MsummaryCls(self._core, self._cmd_group)
		return self._msummary

	@property
	def harmonics(self):
		"""harmonics commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_harmonics'):
			from .Harmonics import HarmonicsCls
			self._harmonics = HarmonicsCls(self._core, self._cmd_group)
		return self._harmonics

	def clone(self) -> 'FunctionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FunctionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TableCls:
	"""Table commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("table", core, parent)

	def set(self, columns: enums.StatisticType, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:TABLe \n
		Snippet: driver.applications.k50Spurious.massMemory.store.table.set(columns = enums.StatisticType.ALL, filename = '1', store = repcap.Store.Default) \n
		Exports the selected data from the specified window as a comma-separated list of results, table row by table row, to an
		ASCII file. The decimal separator (decimal point or comma) for floating-point numerals contained in the file is defined
		by method RsFswp.Applications.K30_NoiseFigure.FormatPy.Dexport.Dseparator.set. \n
			:param columns: SELected | ALL Defines which columns to include in the export file. SELected Only the results defined by method RsFswp.Applications.K50_Spurious.Calculate.Ssearch.Table.Column.set are included. ALL All available results are included.
			:param filename: String containing the path and name of the file.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('columns', columns, DataType.Enum, enums.StatisticType), ArgSingle('filename', filename, DataType.String))
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:TABLe {param}'.rstrip())



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, offset: float) -> None:
		"""SCPI: [SENSe]:DDEMod:STANdard:SYNC:OFFSet[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.standard.sync.offset.value.set(offset = 1.0) \n
		This command defines a number of symbols which are ignored before the comparison with the pattern starts. \n
			:param offset: Range: 0 to 15000, Unit: SYMB
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SENSe:DDEMod:STANdard:SYNC:OFFSet:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:STANdard:SYNC:OFFSet[:VALue] \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.standard.sync.offset.value.get() \n
		This command defines a number of symbols which are ignored before the comparison with the pattern starts. \n
			:return: offset: Range: 0 to 15000, Unit: SYMB"""
		response = self._core.io.query_str(f'SENSe:DDEMod:STANdard:SYNC:OFFSet:VALue?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, idn: float, key: str, value: str) -> None:
		"""SCPI: DIAGnostic:HUMS:TAGS:VALue \n
		Snippet: driver.diagnostic.hums.tags.value.set(idn = 1.0, key = '1', value = '1') \n
		Adds or modifies a key-value pair (device tag) . The query returns the key-value pair for a given ID or an empty string
		if the ID is unknown. \n
			:param idn: 0 - 31 ID number of the tag you want to modify or query. To identify the ID number, query all device tags from the system first. For more information, read here method RsFswp.Diagnostic.Hums.Tags.All.get_.
			:param key: String containing key name of the queried tag.
			:param value: String containing value of the queried tag.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('idn', idn, DataType.Float), ArgSingle('key', key, DataType.String), ArgSingle('value', value, DataType.String))
		self._core.io.write(f'DIAGnostic:HUMS:TAGS:VALue {param}'.rstrip())

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Response structure. Fields: \n
			- Idn: float: 0 - 31 ID number of the tag you want to modify or query. To identify the ID number, query all device tags from the system first. For more information, read here [CMDLINK: DIAGnostic:HUMS:TAGS:ALL? CMDLINK].
			- Key: str: String containing key name of the queried tag.
			- Value: str: String containing value of the queried tag."""
		__meta_args_list = [
			ArgStruct.scalar_float('Idn'),
			ArgStruct.scalar_str('Key'),
			ArgStruct.scalar_str('Value')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Idn: float = None
			self.Key: str = None
			self.Value: str = None

	def get(self) -> ValueStruct:
		"""SCPI: DIAGnostic:HUMS:TAGS:VALue \n
		Snippet: value: ValueStruct = driver.diagnostic.hums.tags.value.get() \n
		Adds or modifies a key-value pair (device tag) . The query returns the key-value pair for a given ID or an empty string
		if the ID is unknown. \n
			:return: structure: for return value, see the help for ValueStruct structure arguments."""
		return self._core.io.query_struct(f'DIAGnostic:HUMS:TAGS:VALue?', self.__class__.ValueStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IntegrityCls:
	"""Integrity commands group definition. 15 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("integrity", core, parent)

	@property
	def event(self):
		"""event commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_event'):
			from .Event import EventCls
			self._event = EventCls(self._core, self._cmd_group)
		return self._event

	@property
	def condition(self):
		"""condition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_condition'):
			from .Condition import ConditionCls
			self._condition = ConditionCls(self._core, self._cmd_group)
		return self._condition

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Enable import EnableCls
			self._enable = EnableCls(self._core, self._cmd_group)
		return self._enable

	@property
	def ptransition(self):
		"""ptransition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptransition'):
			from .Ptransition import PtransitionCls
			self._ptransition = PtransitionCls(self._core, self._cmd_group)
		return self._ptransition

	@property
	def ntransition(self):
		"""ntransition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntransition'):
			from .Ntransition import NtransitionCls
			self._ntransition = NtransitionCls(self._core, self._cmd_group)
		return self._ntransition

	@property
	def signal(self):
		"""signal commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_signal'):
			from .Signal import SignalCls
			self._signal = SignalCls(self._core, self._cmd_group)
		return self._signal

	@property
	def uncalibrated(self):
		"""uncalibrated commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_uncalibrated'):
			from .Uncalibrated import UncalibratedCls
			self._uncalibrated = UncalibratedCls(self._core, self._cmd_group)
		return self._uncalibrated

	def clone(self) -> 'IntegrityCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IntegrityCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 66 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def achannel(self):
		"""achannel commands group. 15 Sub-classes, 1 commands."""
		if not hasattr(self, '_achannel'):
			from .Achannel import AchannelCls
			self._achannel = AchannelCls(self._core, self._cmd_group)
		return self._achannel

	@property
	def bandwidth(self):
		"""bandwidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def hspeed(self):
		"""hspeed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hspeed'):
			from .Hspeed import HspeedCls
			self._hspeed = HspeedCls(self._core, self._cmd_group)
		return self._hspeed

	@property
	def ncorrection(self):
		"""ncorrection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncorrection'):
			from .Ncorrection import NcorrectionCls
			self._ncorrection = NcorrectionCls(self._core, self._cmd_group)
		return self._ncorrection

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def value(self):
		"""value commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_value'):
			from .Value import ValueCls
			self._value = ValueCls(self._core, self._cmd_group)
		return self._value

	def set(self, freq_high: float) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH \n
		Snippet: driver.applications.k50Spurious.sense.mixer.harmonic.high.set(freq_high = 1.0) \n
		No command help available \n
			:param freq_high: No help available
		"""
		param = Conversions.decimal_value_to_str(freq_high)
		self._core.io.write(f'SENSe:MIXer:HARMonic:HIGH {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH \n
		Snippet: value: float = driver.applications.k50Spurious.sense.mixer.harmonic.high.get() \n
		No command help available \n
			:return: freq_high: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:HARMonic:HIGH?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'HighCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HighCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SnrCls:
	"""Snr commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("snr", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:SNR \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.snr.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the SNR error measurement performed for digital demodulation. \n
			:param result_type: none SNR value of display points of current sweep AVG Average of SNR values over several sweeps PAVG Average of maximum SNR values over several sweeps PCTL 95% percentile of SNR value over several sweeps PEAK Maximum SNR over all symbols of current sweep PPCT 95% percentile of maximum SNR values over several sweeps PSD Standard deviation of maximum SNR values over several sweeps RPE Maximum value of SNR over several sweeps SDEV Standard deviation of SNR values over several sweeps TPE Maximum SNR over all display points over several sweeps
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:SNR? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RterminatorCls:
	"""Rterminator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rterminator", core, parent)

	def set(self, terminator: enums.GpibTerminator) -> None:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:RTERminator \n
		Snippet: driver.system.communicate.gpib.self.rterminator.set(terminator = enums.GpibTerminator.EOI) \n
		This command selects the GPIB receive terminator. Output of binary data from the instrument to the control computer does
		not require such a terminator change. \n
			:param terminator: LFEOI | EOI LFEOI According to the standard, the terminator in ASCII is LF and/or EOI. EOI For binary data transfers (e.g. trace data) from the control computer to the instrument, the binary code used for LF might be included in the binary data block, and therefore should not be interpreted as a terminator in this particular case. This can be avoided by using only the receive terminator EOI.
		"""
		param = Conversions.enum_scalar_to_str(terminator, enums.GpibTerminator)
		self._core.io.write(f'SYSTem:COMMunicate:GPIB:SELF:RTERminator {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GpibTerminator:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:RTERminator \n
		Snippet: value: enums.GpibTerminator = driver.system.communicate.gpib.self.rterminator.get() \n
		This command selects the GPIB receive terminator. Output of binary data from the instrument to the control computer does
		not require such a terminator change. \n
			:return: terminator: LFEOI | EOI LFEOI According to the standard, the terminator in ASCII is LF and/or EOI. EOI For binary data transfers (e.g. trace data) from the control computer to the instrument, the binary code used for LF might be included in the binary data block, and therefore should not be interpreted as a terminator in this particular case. This can be avoided by using only the receive terminator EOI."""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:GPIB:SELF:RTERminator?')
		return Conversions.str_to_scalar_enum(response, enums.GpibTerminator)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BlightingCls:
	"""Blighting commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("blighting", core, parent)

	def set(self, brightness: float) -> None:
		"""SCPI: DISPlay:BLIGhting \n
		Snippet: driver.display.blighting.set(brightness = 1.0) \n
		No command help available \n
			:param brightness: No help available
		"""
		param = Conversions.decimal_value_to_str(brightness)
		self._core.io.write(f'DISPlay:BLIGhting {param}')

	def get(self) -> float:
		"""SCPI: DISPlay:BLIGhting \n
		Snippet: value: float = driver.display.blighting.get() \n
		No command help available \n
			:return: brightness: No help available"""
		response = self._core.io.query_str(f'DISPlay:BLIGhting?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.TriggerSourceD) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:SOURce \n
		Snippet: driver.sense.sweep.egate.source.set(source = enums.TriggerSourceD.EXT2) \n
		No command help available \n
			:param source: No help available
		"""
		param = Conversions.enum_scalar_to_str(source, enums.TriggerSourceD)
		self._core.io.write(f'SENSe:SWEep:EGATe:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TriggerSourceD:
		"""SCPI: [SENSe]:SWEep:EGATe:SOURce \n
		Snippet: value: enums.TriggerSourceD = driver.sense.sweep.egate.source.get() \n
		No command help available \n
			:return: source: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSourceD)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalcCls:
	"""Calc commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calc", core, parent)

	def set(self, select_res_range_nr: float) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:MBURst:CALC \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.mburst.calc.set(select_res_range_nr = 1.0) \n
		Sets the result range to be displayed after a single sweep (e.g. a burst number) . \n
			:param select_res_range_nr: No help available
		"""
		param = Conversions.decimal_value_to_str(select_res_range_nr)
		self._core.io.write(f'SENSe:DDEMod:SEARch:MBURst:CALC {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:SEARch:MBURst:CALC \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.search.mburst.calc.get() \n
		Sets the result range to be displayed after a single sweep (e.g. a burst number) . \n
			:return: select_res_range_nr: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:MBURst:CALC?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetupCls:
	"""Setup commands group definition. 10 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setup", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def pmode(self):
		"""pmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmode'):
			from .Pmode import PmodeCls
			self._pmode = PmodeCls(self._core, self._cmd_group)
		return self._pmode

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def attRatio(self):
		"""attRatio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_attRatio'):
			from .AttRatio import AttRatioCls
			self._attRatio = AttRatioCls(self._core, self._cmd_group)
		return self._attRatio

	@property
	def cmOffset(self):
		"""cmOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cmOffset'):
			from .CmOffset import CmOffsetCls
			self._cmOffset = CmOffsetCls(self._core, self._cmd_group)
		return self._cmOffset

	@property
	def dmOffset(self):
		"""dmOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmOffset'):
			from .DmOffset import DmOffsetCls
			self._dmOffset = DmOffsetCls(self._core, self._cmd_group)
		return self._dmOffset

	@property
	def pmOffset(self):
		"""pmOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmOffset'):
			from .PmOffset import PmOffsetCls
			self._pmOffset = PmOffsetCls(self._core, self._cmd_group)
		return self._pmOffset

	@property
	def nmOffset(self):
		"""nmOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nmOffset'):
			from .NmOffset import NmOffsetCls
			self._nmOffset = NmOffsetCls(self._core, self._cmd_group)
		return self._nmOffset

	def clone(self) -> 'SetupCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SetupCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, length: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: OUTPut:TRIGger<2|3>:PULSe:LENGth \n
		Snippet: driver.output.trigger.pulse.length.set(length = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		This command defines the length of the pulse generated at the trigger output. \n
			:param length: Pulse length in seconds. Unit: S
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(length)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'OUTPut:TRIGger{triggerPort_cmd_val}:PULSe:LENGth {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: OUTPut:TRIGger<2|3>:PULSe:LENGth \n
		Snippet: value: float = driver.output.trigger.pulse.length.get(triggerPort = repcap.TriggerPort.Default) \n
		This command defines the length of the pulse generated at the trigger output. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: length: Pulse length in seconds. Unit: S"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'OUTPut:TRIGger{triggerPort_cmd_val}:PULSe:LENGth?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, limit_value: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:OOFFset:MEAN:VALue \n
		Snippet: driver.applications.k70Vsa.calculate.limit.maccuracy.ooffset.mean.value.set(limit_value = 1.0, window = repcap.Window.Default) \n
		This command defines the upper limit for the current, peak or mean I/Q offset. Note that the limits for the current and
		the peak value are always kept identical. \n
			:param limit_value: Range: -200.0 to 0.0, Unit: DB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(limit_value)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:OOFFset:MEAN:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:OOFFset:MEAN:VALue \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.limit.maccuracy.ooffset.mean.value.get(window = repcap.Window.Default) \n
		This command defines the upper limit for the current, peak or mean I/Q offset. Note that the limits for the current and
		the peak value are always kept identical. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: limit_value: Range: -200.0 to 0.0, Unit: DB"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:OOFFset:MEAN:VALue?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:SHIMmediate:STATe \n
		Snippet: driver.system.shImmediate.state.set(state = False) \n
		Determines when the remote commands that change hardware settings on the R&S FSWP are executed. Regardless of this
		setting, the firmware automatically sets the hardware when a sweep is started. This setting is not changed by the preset
		function. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Remote commands that cause changes to the hardware are only executed when the SYSTem:SHIMmediate ONCE command is executed. ON | 1 Remote commands are always executed immediately when they are received by the instrument.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:SHIMmediate:STATe {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:SHIMmediate:STATe \n
		Snippet: value: bool = driver.system.shImmediate.state.get() \n
		Determines when the remote commands that change hardware settings on the R&S FSWP are executed. Regardless of this
		setting, the firmware automatically sets the hardware when a sweep is started. This setting is not changed by the preset
		function. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Remote commands that cause changes to the hardware are only executed when the SYSTem:SHIMmediate ONCE command is executed. ON | 1 Remote commands are always executed immediately when they are received by the instrument."""
		response = self._core.io.query_str(f'SYSTem:SHIMmediate:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqCls:
	"""Iq commands group definition. 18 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iq", core, parent)

	@property
	def balanced(self):
		"""balanced commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_balanced'):
			from .Balanced import BalancedCls
			self._balanced = BalancedCls(self._core, self._cmd_group)
		return self._balanced

	@property
	def osc(self):
		"""osc commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_osc'):
			from .Osc import OscCls
			self._osc = OscCls(self._core, self._cmd_group)
		return self._osc

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def fullscale(self):
		"""fullscale commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fullscale'):
			from .Fullscale import FullscaleCls
			self._fullscale = FullscaleCls(self._core, self._cmd_group)
		return self._fullscale

	@property
	def impedance(self):
		"""impedance commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_impedance'):
			from .Impedance import ImpedanceCls
			self._impedance = ImpedanceCls(self._core, self._cmd_group)
		return self._impedance

	def clone(self) -> 'IqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Count: float: Total number of registered SNMP users.
			- Name: str: List of all user names as a comma-separated list."""
		__meta_args_list = [
			ArgStruct.scalar_float('Count'),
			ArgStruct.scalar_str('Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Count: float = None
			self.Name: str = None

	def get(self) -> GetStruct:
		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER:ALL \n
		Snippet: value: GetStruct = driver.system.communicate.snmp.usm.user.all.get() \n
		Queries the number of users and a list of all SNMP users for SNMPv3.
			INTRO_CMD_HELP: Prerequisites for this command: \n
			- Select SNMPv3 (method RsFswp.System.Communicate.Snmp.Version.set) . \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:COMMunicate:SNMP:USM:USER:ALL?', self.__class__.GetStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StimeCls:
	"""Stime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stime", core, parent)

	def set(self, settling_time: float) -> None:
		"""SCPI: SYSTem:CONFigure:DUT:STIMe \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.dut.stime.set(settling_time = 1.0) \n
		This command defines the settling time of the noise source. \n
			:param settling_time: Range: 0 s to 20 s, Unit: S
		"""
		param = Conversions.decimal_value_to_str(settling_time)
		self._core.io.write(f'SYSTem:CONFigure:DUT:STIMe {param}')

	def get(self) -> float:
		"""SCPI: SYSTem:CONFigure:DUT:STIMe \n
		Snippet: value: float = driver.applications.k30NoiseFigure.system.configure.dut.stime.get() \n
		This command defines the settling time of the noise source. \n
			:return: settling_time: Range: 0 s to 20 s, Unit: S"""
		response = self._core.io.query_str(f'SYSTem:CONFigure:DUT:STIMe?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LongCls:
	"""Long commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("long", core, parent)

	def set(self, directory: str) -> None:
		"""SCPI: MMEMory:CATalog:LONG \n
		Snippet: driver.massMemory.catalog.long.set(directory = '1') \n
		This command returns the contents of a particular directory with additional information about the files. \n
			:param directory: String containing the path and directory. If you leave out the path, the command returns the contents of the directory selected with method RsFswp.MassMemory.CurrentDirectory.set. The path may be relative or absolute. Using wildcards ('*') is possible to query a certain type of files only.
		"""
		param = Conversions.value_to_quoted_str(directory)
		self._core.io.write(f'MMEMory:CATalog:LONG {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:CATalog:LONG \n
		Snippet: value: str = driver.massMemory.catalog.long.get() \n
		This command returns the contents of a particular directory with additional information about the files. \n
			:return: directory: String containing the path and directory. If you leave out the path, the command returns the contents of the directory selected with method RsFswp.MassMemory.CurrentDirectory.set. The path may be relative or absolute. Using wildcards ('*') is possible to query a certain type of files only."""
		response = self._core.io.query_str(f'MMEMory:CATalog:LONG?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	def set(self, fsk_ref_dev: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:FSK:DEViation:REFerence:RELative \n
		Snippet: driver.applications.k70Vsa.calculate.fsk.deviation.reference.relative.set(fsk_ref_dev = 1.0, window = repcap.Window.Default) \n
		This command defines the deviation to the reference frequency for FSK modulation as a multiple of the symbol rate. \n
			:param fsk_ref_dev: Range: 0.1 to 60, Unit: none
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(fsk_ref_dev)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:FSK:DEViation:REFerence:RELative {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:FSK:DEViation:REFerence:RELative \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.fsk.deviation.reference.relative.get(window = repcap.Window.Default) \n
		This command defines the deviation to the reference frequency for FSK modulation as a multiple of the symbol rate. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: fsk_ref_dev: Range: 0.1 to 60, Unit: none"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:FSK:DEViation:REFerence:RELative?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DistortionCls:
	"""Distortion commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("distortion", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Distortion_Pct: float: No parameter help available
			- Distortion_Db: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Distortion_Pct'),
			ArgStruct.scalar_float('Distortion_Db')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Distortion_Pct: float = None
			self.Distortion_Db: float = None

	def get(self, result: enums.ResultTypeD = None, window=repcap.Window.Default, marker=repcap.Marker.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:HARMonics:DISTortion \n
		Snippet: value: GetStruct = driver.calculate.marker.function.harmonics.distortion.get(result = enums.ResultTypeD.TOTal, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param result: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('result', result, DataType.Enum, enums.ResultTypeD, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:HARMonics:DISTortion? {param}'.rstrip(), self.__class__.GetStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, psk_format: enums.PskFormat) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:PSK:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.psk.formatPy.set(psk_format = enums.PskFormat.DIFFerential) \n
		Together with DDEMod:PATT:PSK:NST, this command defines the demodulation order for PSK for the pattern (see also
		[SENSe:]DDEMod:PATTern:PSK:NSTate) .
			Table Header: NSTATe / <PSKformat> / Order \n
			- 2 / NORMal / BPSK
			- 8 / NORMal / 8PSK
			- 8 / DIFFerential / D8PSK
		This command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param psk_format: NORMal | DIFFerential
		"""
		param = Conversions.enum_scalar_to_str(psk_format, enums.PskFormat)
		self._core.io.write(f'SENSe:DDEMod:PATTern:PSK:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PskFormat:
		"""SCPI: [SENSe]:DDEMod:PATTern:PSK:FORMat \n
		Snippet: value: enums.PskFormat = driver.applications.k70Vsa.sense.ddemod.pattern.psk.formatPy.get() \n
		Together with DDEMod:PATT:PSK:NST, this command defines the demodulation order for PSK for the pattern (see also
		[SENSe:]DDEMod:PATTern:PSK:NSTate) .
			Table Header: NSTATe / <PSKformat> / Order \n
			- 2 / NORMal / BPSK
			- 8 / NORMal / 8PSK
			- 8 / DIFFerential / D8PSK
		This command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: psk_format: NORMal | DIFFerential"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:PSK:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.PskFormat)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, filter_type: enums.FilterTypeA) -> None:
		"""SCPI: [SENSe]:BWIDth:DEMod:TYPE \n
		Snippet: driver.sense.bandwidth.demod.typePy.set(filter_type = enums.FilterTypeA.FLAT) \n
		This command defines the type of demodulation filter to be used. This command is identical to SENS:ADEM:BAND:DEM:TYPE: \n
			:param filter_type: FLAT Standard flat demodulation filter GAUSs Gaussian filter for optimized settling behavior
		"""
		param = Conversions.enum_scalar_to_str(filter_type, enums.FilterTypeA)
		self._core.io.write(f'SENSe:BWIDth:DEMod:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FilterTypeA:
		"""SCPI: [SENSe]:BWIDth:DEMod:TYPE \n
		Snippet: value: enums.FilterTypeA = driver.sense.bandwidth.demod.typePy.get() \n
		This command defines the type of demodulation filter to be used. This command is identical to SENS:ADEM:BAND:DEM:TYPE: \n
			:return: filter_type: FLAT Standard flat demodulation filter GAUSs Gaussian filter for optimized settling behavior"""
		response = self._core.io.query_str(f'SENSe:BWIDth:DEMod:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FilterTypeA)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ActiveCls:
	"""Active commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("active", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:TRACe[:ACTive] \n
		Snippet: driver.massMemory.select.channel.item.trace.active.set(state = False) \n
		This command includes or excludes trace data when storing or loading a configuration file. Depending on the used command,
		either the items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those from the currently selected
		channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:SELect:CHANnel:ITEM:TRACe:ACTive {param}')

	def get(self) -> bool:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:TRACe[:ACTive] \n
		Snippet: value: bool = driver.massMemory.select.channel.item.trace.active.get() \n
		This command includes or excludes trace data when storing or loading a configuration file. Depending on the used command,
		either the items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those from the currently selected
		channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'MMEMory:SELect:CHANnel:ITEM:TRACe:ACTive?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ControlCls:
	"""Control commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("control", core, parent)

	def set(self, mode: enums.AutoManualMode) -> None:
		"""SCPI: [SENSe]:CONFigure:CONTrol \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.control.set(mode = enums.AutoManualMode.AUTO) \n
		This command selects the measurement mode for the hot and cold power measurements. Note that selecting a noise source
		with resistor characteristics with [SENSe:]CORRection:ENR:CALibration:TYPE or [SENSe:]CORRection:ENR[:MEASurement]:TYPE
		automatically selects manual measurement mode. \n
			:param mode: AUTO | MANual AUTO Performs the Power (Hot) and Power (Cold) measurement in one step. MANual Performs the Power (Hot) and Power (Cold) measurement in two separate steps.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
		self._core.io.write(f'SENSe:CONFigure:CONTrol {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:CONFigure:CONTrol \n
		Snippet: value: enums.AutoManualMode = driver.applications.k30NoiseFigure.sense.configure.control.get() \n
		This command selects the measurement mode for the hot and cold power measurements. Note that selecting a noise source
		with resistor characteristics with [SENSe:]CORRection:ENR:CALibration:TYPE or [SENSe:]CORRection:ENR[:MEASurement]:TYPE
		automatically selects manual measurement mode. \n
			:return: mode: AUTO | MANual AUTO Performs the Power (Hot) and Power (Cold) measurement in one step. MANual Performs the Power (Hot) and Power (Cold) measurement in two separate steps."""
		response = self._core.io.query_str(f'SENSe:CONFigure:CONTrol?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectionCls:
	"""Correction commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correction", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:CONFigure:CORRection \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.correction.set() \n
		This command configures the software to perform calibration measurements. Using method RsFswp.Applications.
		K30_NoiseFigure.Initiate.Immediate.set then initiates a calibration instead of the actual measurement, until you
		deliberately select one of the normal measurements again with one of the following commands.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- [SENSe:]CONFigure:FREQuency:CONTinuous
			- [SENSe:]CONFigure:FREQuency:SINGle
			- [SENSe:]CONFigure:LIST:CONTinuous
			- [SENSe:]CONFigure:LIST:SINGle
		Note that calibration data is used only when the second stage correction mode has been turned on with
		[SENSe:]CORRection[:STATe]. \n
		"""
		self._core.io.write(f'SENSe:CONFigure:CORRection')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:CONFigure:CORRection \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.correction.set_with_opc() \n
		This command configures the software to perform calibration measurements. Using method RsFswp.Applications.
		K30_NoiseFigure.Initiate.Immediate.set then initiates a calibration instead of the actual measurement, until you
		deliberately select one of the normal measurements again with one of the following commands.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- [SENSe:]CONFigure:FREQuency:CONTinuous
			- [SENSe:]CONFigure:FREQuency:SINGle
			- [SENSe:]CONFigure:LIST:CONTinuous
			- [SENSe:]CONFigure:LIST:SINGle
		Note that calibration data is used only when the second stage correction mode has been turned on with
		[SENSe:]CORRection[:STATe]. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CONFigure:CORRection', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RatioCls:
	"""Ratio commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ratio", core, parent)

	def set(self, unit: enums.UnitMode, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: UNIT:PMETer<p>:POWer:RATio \n
		Snippet: driver.unit.pmeter.power.ratio.set(unit = enums.UnitMode.DB, powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param unit: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.UnitMode)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'UNIT:PMETer{powerMeter_cmd_val}:POWer:RATio {param}')

	# noinspection PyTypeChecker
	def get(self, powerMeter=repcap.PowerMeter.Default) -> enums.UnitMode:
		"""SCPI: UNIT:PMETer<p>:POWer:RATio \n
		Snippet: value: enums.UnitMode = driver.unit.pmeter.power.ratio.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: unit: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'UNIT:PMETer{powerMeter_cmd_val}:POWer:RATio?')
		return Conversions.str_to_scalar_enum(response, enums.UnitMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalibrationCls:
	"""Calibration commands group definition. 7 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calibration", core, parent)

	@property
	def sns(self):
		"""sns commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sns'):
			from .Sns import SnsCls
			self._sns = SnsCls(self._core, self._cmd_group)
		return self._sns

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def spot(self):
		"""spot commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_spot'):
			from .Spot import SpotCls
			self._spot = SpotCls(self._core, self._cmd_group)
		return self._spot

	@property
	def table(self):
		"""table commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_table'):
			from .Table import TableCls
			self._table = TableCls(self._core, self._cmd_group)
		return self._table

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'CalibrationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalibrationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StreamCls:
	"""Stream commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stream", core, parent)

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, channel: str) -> None:
		"""SCPI: MMEMory:LOAD:IQ:STReam \n
		Snippet: driver.applications.k70Vsa.massMemory.load.iq.stream.set(channel = '1') \n
		No command help available \n
			:param channel: No help available
		"""
		param = Conversions.value_to_quoted_str(channel)
		self._core.io.write(f'MMEMory:LOAD:IQ:STReam {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:LOAD:IQ:STReam \n
		Snippet: value: str = driver.applications.k70Vsa.massMemory.load.iq.stream.get() \n
		No command help available \n
			:return: channel: No help available"""
		response = self._core.io.query_str(f'MMEMory:LOAD:IQ:STReam?')
		return trim_str_response(response)

	def clone(self) -> 'StreamCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StreamCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, table_name: str) -> None:
		"""SCPI: [SENSe]:CORRection:LOSS:INPut:TABLe:SELect \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.loss.inputPy.table.select.set(table_name = '1') \n
		This command selects an input loss table. \n
			:param table_name: String containing the table name.
		"""
		param = Conversions.value_to_quoted_str(table_name)
		self._core.io.write(f'SENSe:CORRection:LOSS:INPut:TABLe:SELect {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:CORRection:LOSS:INPut:TABLe:SELect \n
		Snippet: value: str = driver.applications.k30NoiseFigure.sense.correction.loss.inputPy.table.select.get() \n
		This command selects an input loss table. \n
			:return: table_name: String containing the table name."""
		response = self._core.io.query_str(f'SENSe:CORRection:LOSS:INPut:TABLe:SELect?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class O640Cls:
	"""O640 commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("o640", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:ROSCillator:O640 \n
		Snippet: driver.sense.roscillator.o640.set(state = False) \n
		This command turns the output of a reference signal on the corresponding connector ('Ref Output') on and off.
		[SENSe:]ROSCillator:O100: Provides a 100 MHz reference signal on corresponding connector. [SENSe:]ROSCillator:O640:
		Provides a 640 MHz reference signal on corresponding connector. \n
			:param state: ON | OFF | 1 | 0 OFF | 0 Switches the reference off. ON | 1 Switches the reference on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write_with_opc(f'SENSe:ROSCillator:O640 {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:ROSCillator:O640 \n
		Snippet: value: bool = driver.sense.roscillator.o640.get() \n
		This command turns the output of a reference signal on the corresponding connector ('Ref Output') on and off.
		[SENSe:]ROSCillator:O100: Provides a 100 MHz reference signal on corresponding connector. [SENSe:]ROSCillator:O640:
		Provides a 640 MHz reference signal on corresponding connector. \n
			:return: state: ON | OFF | 1 | 0 OFF | 0 Switches the reference off. ON | 1 Switches the reference on"""
		response = self._core.io.query_str_with_opc(f'SENSe:ROSCillator:O640?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SweepCls:
	"""Sweep commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sweep", core, parent)

	@property
	def stop(self):
		"""stop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stop'):
			from .Stop import StopCls
			self._stop = StopCls(self._core, self._cmd_group)
		return self._stop

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def avg(self):
		"""avg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_avg'):
			from .Avg import AvgCls
			self._avg = AvgCls(self._core, self._cmd_group)
		return self._avg

	@property
	def fdrift(self):
		"""fdrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdrift'):
			from .Fdrift import FdriftCls
			self._fdrift = FdriftCls(self._core, self._cmd_group)
		return self._fdrift

	@property
	def mdrift(self):
		"""mdrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mdrift'):
			from .Mdrift import MdriftCls
			self._mdrift = MdriftCls(self._core, self._cmd_group)
		return self._mdrift

	@property
	def ldrift(self):
		"""ldrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ldrift'):
			from .Ldrift import LdriftCls
			self._ldrift = LdriftCls(self._core, self._cmd_group)
		return self._ldrift

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import StartCls
			self._start = StartCls(self._core, self._cmd_group)
		return self._start

	def clone(self) -> 'SweepCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SweepCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LowerCls:
	"""Lower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lower", core, parent)

	def set(self, hysteresis_lower: float) -> None:
		"""SCPI: [SENSe]:ADJust:CONFigure[:HYSTeresis]:LOWer \n
		Snippet: driver.applications.k70Vsa.sense.adjust.configure.hysteresis.lower.set(hysteresis_lower = 1.0) \n
		When the reference level is adjusted automatically using the [SENSe:]ADJust:LEVel command, the internal attenuators and
		the preamplifier are also adjusted. To avoid frequent adaptation due to small changes in the input signal, you can define
		a hysteresis. This setting defines a lower threshold the signal must fall below (compared to the last measurement) before
		the reference level is adapted automatically. \n
			:param hysteresis_lower: Range: 0 dB to 200 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(hysteresis_lower)
		self._core.io.write(f'SENSe:ADJust:CONFigure:HYSTeresis:LOWer {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADJust:CONFigure[:HYSTeresis]:LOWer \n
		Snippet: value: float = driver.applications.k70Vsa.sense.adjust.configure.hysteresis.lower.get() \n
		When the reference level is adjusted automatically using the [SENSe:]ADJust:LEVel command, the internal attenuators and
		the preamplifier are also adjusted. To avoid frequent adaptation due to small changes in the input signal, you can define
		a hysteresis. This setting defines a lower threshold the signal must fall below (compared to the last measurement) before
		the reference level is adapted automatically. \n
			:return: hysteresis_lower: No help available"""
		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:HYSTeresis:LOWer?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtableCls:
	"""Mtable commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtable", core, parent)

	def set(self, display_mode: enums.AutoMode) -> None:
		"""SCPI: DISPlay:MTABle \n
		Snippet: driver.applications.k50Spurious.display.mtable.set(display_mode = enums.AutoMode.AUTO) \n
		No command help available \n
			:param display_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(display_mode, enums.AutoMode)
		self._core.io.write(f'DISPlay:MTABle {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoMode:
		"""SCPI: DISPlay:MTABle \n
		Snippet: value: enums.AutoMode = driver.applications.k50Spurious.display.mtable.get() \n
		No command help available \n
			:return: display_mode: No help available"""
		response = self._core.io.query_str(f'DISPlay:MTABle?')
		return Conversions.str_to_scalar_enum(response, enums.AutoMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	def set(self, center: float) -> None:
		"""SCPI: [SENSe]:CREFerence:PDETect:RANGe:CENTer \n
		Snippet: driver.applications.k50Spurious.sense.creference.pdetect.range.center.set(center = 1.0) \n
		Defines the center of the range in which the maximum peak is searched. \n
			:param center: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(center)
		self._core.io.write(f'SENSe:CREFerence:PDETect:RANGe:CENTer {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CREFerence:PDETect:RANGe:CENTer \n
		Snippet: value: float = driver.applications.k50Spurious.sense.creference.pdetect.range.center.get() \n
		Defines the center of the range in which the maximum peak is searched. \n
			:return: center: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:CREFerence:PDETect:RANGe:CENTer?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def get(self, trace: enums.NoiseFigureResultCustom, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:Y \n
		Snippet: value: float = driver.applications.k30NoiseFigure.calculate.marker.y.get(trace = enums.NoiseFigureResultCustom.CPCold, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		Queries the result at the position of the specified marker. \n
			:param trace: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: Selects the result. CPCold Queries calibration power (cold) results. CPHot Queries calibration power (hot) results. CYFactor Queries calibration 'y-factor' results. GAIN Queries 'gain' results. NOISe Queries 'noise figure' results. NUNCertainty Queries the 'noise figure' uncertainty results. PCOLd Queries power (cold) results. PHOT Queries power (hot) results. TEMPerature Queries 'noise temperature' results. YFACtor Queries 'y-factor' results."""
		param = Conversions.enum_scalar_to_str(trace, enums.NoiseFigureResultCustom)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:Y? {param}')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BiosInfoCls:
	"""BiosInfo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("biosInfo", core, parent)

	def get(self) -> str:
		"""SCPI: DIAGnostic:SERVice:BIOSinfo \n
		Snippet: value: str = driver.diagnostic.service.biosInfo.get() \n
		This command queries the BIOS version of the CPU board. \n
			:return: bios_information: String containing the BIOS version."""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:BIOSinfo?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def ratio(self):
		"""ratio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ratio'):
			from .Ratio import RatioCls
			self._ratio = RatioCls(self._core, self._cmd_group)
		return self._ratio

	def set(self, unit: enums.PowerMeterUnit, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: UNIT:PMETer<p>:POWer \n
		Snippet: driver.unit.pmeter.power.set(unit = enums.PowerMeterUnit.DBM, powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param unit: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.PowerMeterUnit)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'UNIT:PMETer{powerMeter_cmd_val}:POWer {param}')

	# noinspection PyTypeChecker
	def get(self, powerMeter=repcap.PowerMeter.Default) -> enums.PowerMeterUnit:
		"""SCPI: UNIT:PMETer<p>:POWer \n
		Snippet: value: enums.PowerMeterUnit = driver.unit.pmeter.power.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: unit: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'UNIT:PMETer{powerMeter_cmd_val}:POWer?')
		return Conversions.str_to_scalar_enum(response, enums.PowerMeterUnit)

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, display_pps_mode: enums.AutoManualMode, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:PRATe:AUTO \n
		Snippet: driver.applications.k70Vsa.display.window.prate.auto.set(display_pps_mode = enums.AutoManualMode.AUTO, window = repcap.Window.Default) \n
		Defines the number of display points that are displayed per symbol automatically, i.e. according to [SENSe:]DDEMod:PRATe.
		To define a different number of points per symbol for display, use the MANual parameter and the method RsFswp.
		Applications.K70_Vsa.Display.Window.Prate.Value.set command. \n
			:param display_pps_mode: AUTO | MANual
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(display_pps_mode, enums.AutoManualMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:PRATe:AUTO {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.AutoManualMode:
		"""SCPI: DISPlay[:WINDow<n>]:PRATe:AUTO \n
		Snippet: value: enums.AutoManualMode = driver.applications.k70Vsa.display.window.prate.auto.get(window = repcap.Window.Default) \n
		Defines the number of display points that are displayed per symbol automatically, i.e. according to [SENSe:]DDEMod:PRATe.
		To define a different number of points per symbol for display, use the MANual parameter and the method RsFswp.
		Applications.K70_Vsa.Display.Window.Prate.Value.set command. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: display_pps_mode: AUTO | MANual"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:PRATe:AUTO?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EnableCls:
	"""Enable commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	def set(self, summary_bit: int) -> None:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: driver.status.operation.enable.set(summary_bit = 1) \n
		These commands control the ENABle part of a register. The ENABle part allows true conditions in the EVENt part of the
		status register to bereported in the summary bit. If a bit is 1 in the enable register and its associated event bit
		transitions to true, a positive transition will occur in the summary bit reported to the next higher level. \n
			:param summary_bit: No help available
		"""
		param = Conversions.decimal_value_to_str(summary_bit)
		self._core.io.write(f'STATus:OPERation:ENABle {param}')

	def get(self) -> int:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: value: int = driver.status.operation.enable.get() \n
		These commands control the ENABle part of a register. The ENABle part allows true conditions in the EVENt part of the
		status register to bereported in the summary bit. If a bit is 1 in the enable register and its associated event bit
		transitions to true, a positive transition will occur in the summary bit reported to the next higher level. \n
			:return: summary_bit: No help available"""
		response = self._core.io.query_str(f'STATus:OPERation:ENABle?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdroopCls:
	"""Adroop commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("adroop", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:ADRoop \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.adroop.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the amplitude droop error measurement performed for digital demodulation. The output
		values are the same as those provided in the 'Modulation Accuracy' table (see 'Result summary') . \n
			:param result_type: none Amplitude droop in dB/symbol (for current sweep) AVG Amplitude droop in dB/symbol, evaluating the linear average value over several sweeps RPE Peak value for amplitude droop over several sweeps SDEV Standard deviation of amplitude droop PCTL 95 percentile value of amplitude droop
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:ADRoop? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, vert_line_abs_pos: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TLABs[:VALue] \n
		Snippet: driver.applications.k70Vsa.calculate.tlAbs.value.set(vert_line_abs_pos = 1.0, window = repcap.Window.Default) \n
		Defines or queries the x-value of the absolute vertical line in the specified window. This command is only available for
		eye diagrams, and only if an absolute vertical line is already available in the diagram (see method RsFswp.Applications.
		K70_Vsa.Calculate.TlAbs.State.set) . \n
			:param vert_line_abs_pos: X-value of the absolute vertical line. Unit: SYMB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(vert_line_abs_pos)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TLABs:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:TLABs[:VALue] \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.tlAbs.value.get(window = repcap.Window.Default) \n
		Defines or queries the x-value of the absolute vertical line in the specified window. This command is only available for
		eye diagrams, and only if an absolute vertical line is already available in the diagram (see method RsFswp.Applications.
		K70_Vsa.Calculate.TlAbs.State.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: vert_line_abs_pos: X-value of the absolute vertical line. Unit: SYMB"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TLABs:VALue?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalculateCls:
	"""Calculate commands group definition. 66 total commands, 4 Subgroups, 0 group commands
	Repeated Capability: Window, default value after init: Window.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calculate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_window_get', 'repcap_window_set', repcap.Window.Nr1)

	def repcap_window_set(self, window: repcap.Window) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Window.Default
		Default value after init: Window.Nr1"""
		self._cmd_group.set_repcap_enum_value(window)

	def repcap_window_get(self) -> repcap.Window:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def limit(self):
		"""limit commands group. 12 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def deltaMarker(self):
		"""deltaMarker commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_deltaMarker'):
			from .DeltaMarker import DeltaMarkerCls
			self._deltaMarker = DeltaMarkerCls(self._core, self._cmd_group)
		return self._deltaMarker

	@property
	def marker(self):
		"""marker commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def uncertainty(self):
		"""uncertainty commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_uncertainty'):
			from .Uncertainty import UncertaintyCls
			self._uncertainty = UncertaintyCls(self._core, self._cmd_group)
		return self._uncertainty

	def clone(self) -> 'CalculateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalculateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RangeCls:
	"""Range commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("range", core, parent)

	def set(self, range_type: enums.IqRangeType, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:IQ:RANGe \n
		Snippet: driver.massMemory.store.iq.range.set(range_type = enums.IqRangeType.CAPTure, store = repcap.Store.Default) \n
		No command help available \n
			:param range_type: No help available
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.enum_scalar_to_str(range_type, enums.IqRangeType)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:IQ:RANGe {param}')

	# noinspection PyTypeChecker
	def get(self, store=repcap.Store.Default) -> enums.IqRangeType:
		"""SCPI: MMEMory:STORe<n>:IQ:RANGe \n
		Snippet: value: enums.IqRangeType = driver.massMemory.store.iq.range.get(store = repcap.Store.Default) \n
		No command help available \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: range_type: No help available"""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str(f'MMEMory:STORe{store_cmd_val}:IQ:RANGe?')
		return Conversions.str_to_scalar_enum(response, enums.IqRangeType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HslCls:
	"""Hsl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hsl", core, parent)

	def set(self, hue: float, sat: float, lum: float, item=repcap.Item.Default) -> None:
		"""SCPI: HCOPy:CMAP<it>:HSL \n
		Snippet: driver.hardCopy.cmap.hsl.set(hue = 1.0, sat = 1.0, lum = 1.0, item = repcap.Item.Default) \n
		This command selects the color for various screen elements in print jobs. \n
			:param hue: hue tint Range: 0 to 1
			:param sat: sat saturation Range: 0 to 1
			:param lum: lum brightness Range: 0 to 1
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('hue', hue, DataType.Float), ArgSingle('sat', sat, DataType.Float), ArgSingle('lum', lum, DataType.Float))
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		self._core.io.write(f'HCOPy:CMAP{item_cmd_val}:HSL {param}'.rstrip())

	# noinspection PyTypeChecker
	class HslStruct(StructBase):
		"""Response structure. Fields: \n
			- Hue: float: hue tint Range: 0 to 1
			- Sat: float: sat saturation Range: 0 to 1
			- Lum: float: lum brightness Range: 0 to 1"""
		__meta_args_list = [
			ArgStruct.scalar_float('Hue'),
			ArgStruct.scalar_float('Sat'),
			ArgStruct.scalar_float('Lum')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hue: float = None
			self.Sat: float = None
			self.Lum: float = None

	def get(self, item=repcap.Item.Default) -> HslStruct:
		"""SCPI: HCOPy:CMAP<it>:HSL \n
		Snippet: value: HslStruct = driver.hardCopy.cmap.hsl.get(item = repcap.Item.Default) \n
		This command selects the color for various screen elements in print jobs. \n
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
			:return: structure: for return value, see the help for HslStruct structure arguments."""
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		return self._core.io.query_struct(f'HCOPy:CMAP{item_cmd_val}:HSL?', self.__class__.HslStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def get(self) -> bytes:
		"""SCPI: DIAGnostic:HUMS:TAGS:ALL \n
		Snippet: value: bytes = driver.diagnostic.hums.tags.all.get() \n
		Queries all key-value tags that you have assigend to the instrument. Depending on the set data format, the queried data
		is either displayed in XML or JSON format. For more information about setting the data format, see method RsFswp.
		Diagnostic.Hums.FormatPy.set. \n
			:return: tags_info: No help available"""
		response = self._core.io.query_bin_block_ERROR(f'DIAGnostic:HUMS:TAGS:ALL?')
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TreportCls:
	"""Treport commands group definition. 29 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("treport", core, parent)

	@property
	def append(self):
		"""append commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_append'):
			from .Append import AppendCls
			self._append = AppendCls(self._core, self._cmd_group)
		return self._append

	@property
	def description(self):
		"""description commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_description'):
			from .Description import DescriptionCls
			self._description = DescriptionCls(self._core, self._cmd_group)
		return self._description

	@property
	def item(self):
		"""item commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_item'):
			from .Item import ItemCls
			self._item = ItemCls(self._core, self._cmd_group)
		return self._item

	@property
	def new(self):
		"""new commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_new'):
			from .New import NewCls
			self._new = NewCls(self._core, self._cmd_group)
		return self._new

	@property
	def pageSize(self):
		"""pageSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pageSize'):
			from .PageSize import PageSizeCls
			self._pageSize = PageSizeCls(self._core, self._cmd_group)
		return self._pageSize

	@property
	def pcolors(self):
		"""pcolors commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pcolors'):
			from .Pcolors import PcolorsCls
			self._pcolors = PcolorsCls(self._core, self._cmd_group)
		return self._pcolors

	@property
	def pagecount(self):
		"""pagecount commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pagecount'):
			from .Pagecount import PagecountCls
			self._pagecount = PagecountCls(self._core, self._cmd_group)
		return self._pagecount

	@property
	def tdDtamp(self):
		"""tdDtamp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdDtamp'):
			from .TdDtamp import TdDtampCls
			self._tdDtamp = TdDtampCls(self._core, self._cmd_group)
		return self._tdDtamp

	@property
	def test(self):
		"""test commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_test'):
			from .Test import TestCls
			self._test = TestCls(self._core, self._cmd_group)
		return self._test

	@property
	def title(self):
		"""title commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_title'):
			from .Title import TitleCls
			self._title = TitleCls(self._core, self._cmd_group)
		return self._title

	def clone(self) -> 'TreportCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TreportCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WidebandCls:
	"""Wideband commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wideband", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:PSA:WIDeband \n
		Snippet: driver.system.psa.wideband.set(state = False) \n
		This command defines which option is returned when the *OPT? query is executed, depending on the state of the wideband
		option. It is only available for PSA89600 emulation. \n
			:param state: ON | OFF | HIGH OFF The option is indicated as 'B7J' ON The 40 MHz wideband is used. The option is indicated as 'B7J, 140'. HIGH The 80 MHz wideband is used. The option is indicated as 'B7J, 122'.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:PSA:WIDeband {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:PSA:WIDeband \n
		Snippet: value: bool = driver.system.psa.wideband.get() \n
		This command defines which option is returned when the *OPT? query is executed, depending on the state of the wideband
		option. It is only available for PSA89600 emulation. \n
			:return: state: ON | OFF | HIGH OFF The option is indicated as 'B7J' ON The 40 MHz wideband is used. The option is indicated as 'B7J, 140'. HIGH The 80 MHz wideband is used. The option is indicated as 'B7J, 122'."""
		response = self._core.io.query_str(f'SYSTem:PSA:WIDeband?')
		return Conversions.str_to_bool(response)
